@@ -472,7 +472,7 @@ QC_Plots_Combined_Vln <- function(
 
   # Setup cutoff values
   if (length(x = feature_cutoffs) > 2 || length(x = UMI_cutoffs) > 2 || length(x = mito_cutoffs) > 2) {
-    cli_abort(message = "Length of each cutoff vector cannot be greater than 2.")
+    cli_abort(message = "Length of each cutoff vector cannot be greater than {.field 2 (two)}.")
   }
 
   if (length(x = feature_cutoffs) == 1) {
@@ -546,7 +546,6 @@ QC_Plots_Combined_Vln <- function(
 #' @return A ggplot object
 #'
 #' @import ggplot2
-#' @import viridis
 #' @importFrom cowplot theme_cowplot
 #' @importFrom dplyr filter arrange
 #' @importFrom magrittr "%>%"
@@ -630,7 +629,7 @@ QC_Plot_UMIvsGene <- function(
   if (!is.null(x = meta_gradient_name)) {
     meta_names <- colnames(featurescatter_data)
     if (meta_gradient_name %in% meta_names == FALSE) {
-      cli_abort(message = "The meta data variable '{meta_gradient_name}' could not be found in object@metadata.")
+      cli_abort(message = "The meta data variable {.val {meta_gradient_name}} could not be found in object@metadata.")
     }
   }
 
